@@ -14,7 +14,7 @@ impl PingManager {
     pub fn process_ping(&self, ping_payload: &[u8]) -> Box<[u8]> {
         // read incoming ping index
         let mut reader = PacketReader::new(&ping_payload);
-        let ping_index = reader.get_cursor().read_u16::<BigEndian>().unwrap();
+        let ping_index = reader.cursor().read_u16::<BigEndian>().unwrap();
 
         // write pong payload
         let mut out_bytes = Vec::<u8>::new();
